# TLPCodeRepositoryAnalytics


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**var_schema** | [**EmbeddedModelSchema**](EmbeddedModelSchema.md) |  | [optional] 
**id** | **str** |  | [optional] 

## Example

```python
from openapi_client.models.tlp_code_repository_analytics import TLPCodeRepositoryAnalytics

# TODO update the JSON string below
json = "{}"
# create an instance of TLPCodeRepositoryAnalytics from a JSON string
tlp_code_repository_analytics_instance = TLPCodeRepositoryAnalytics.from_json(json)
# print the JSON string representation of the object
print TLPCodeRepositoryAnalytics.to_json()

# convert the object into a dict
tlp_code_repository_analytics_dict = tlp_code_repository_analytics_instance.to_dict()
# create an instance of TLPCodeRepositoryAnalytics from a dict
tlp_code_repository_analytics_form_dict = tlp_code_repository_analytics.from_dict(tlp_code_repository_analytics_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


